@@ -93,15 +93,12 @@ class KF1(object):
 
         if verbose:
             print('[vipy.dataset.meva.KF1]: Loading %d YAML files' % len(yamlfiles))
-            if len(yamlfiles) > 100 and vipy.globals.max_workers() == 1: 
-                print('[vipy.dataset.meva.KF1]: This takes a while since parsing YAML files in python is painfully slow, consider calling "vipy.globals.max_workers(n)" for n>1 before loading the dataset for parallel parsing')
+            if len(yamlfiles) > 100 and vipy.globals.parallel() <= 1:
+                print('[vipy.dataset.meva.KF1]: This takes a while since parsing YAML files in python is painfully slow, consider calling "vipy.globals.parallel(n)" for n>1 before loading the dataset for parallel parsing')
 
-        # Parallel video annotation
-        if vipy.globals.max_workers() > 1:
-            from vipy.batch import Batch
-            self._vidlist = Batch(list(yamlfiles)).map(lambda tga: self._parse_video(d_videoname_to_path, d_category_to_shortlabel, tga[0], tga[1], tga[2], stride=stride, verbose=verbose, actor=actor)).result()
-        else:
-            self._vidlist = [self._parse_video(d_videoname_to_path, d_category_to_shortlabel, t, g, a, stride=stride, verbose=verbose, actor=actor) for (t,g,a) in yamlfiles]
+        # Parallel video annotation:  set vipy.globals.parallel(n) for n parallel workers for the Batch() processing
+        from vipy.batch import Batch
+        self._vidlist = Batch(list(yamlfiles)).map(lambda tga: self._parse_video(d_videoname_to_path, d_category_to_shortlabel, tga[0], tga[1], tga[2], stride=stride, verbose=verbose, actor=actor)).result()
         self._vidlist = [v for v in self._vidlist if v is not None]
 
         # Merge and dedupe activities and tracks across YAML files for same video, using temporal and spatial IoU association.
@@ -111,8 +108,9 @@ class KF1(object):
         #   which does not work in general.  This requires global track correspondence.  
         if merge:
             print('[vipy.dataset.meva.KF1]: merging videos ...')
-            self._vidlist = [v[0].clone().union(v[1:]) for (f, v) in groupbyasdict([a for vid in self._vidlist for a in vid.activitysplit()], lambda s: s.filename()).items()]
-        
+            V = list(groupbyasdict([a for vid in self._vidlist for a in vid.activitysplit()], lambda s: s.filename()).values())
+            self._vidlist = Batch(V).map(lambda v: v[0].clone().union(v[1:])).result()
+
         # Enforce disjoint causal activities
         #   Due to the arbitrary temporal padding in the annotation definitions, merged causal activiites can overlap
         #   Enforce that causal activities (open/close, enter/exit, pickup/putdown, load/unload) for the same track are disjoint
@@ -257,7 +255,7 @@ class KF1(object):
                 elif v['id1'] not in d_id1_to_track:
                     d_id1_to_track[v['id1']] = Track(category=d_id1_to_category[v['id1']], framerate=framerate, keyframes=[keyframe], boxes=[bbox], boundary='strict')
                 else:
-                    d_id1_to_track[v['id1']].add(keyframe=keyframe, box=bbox)
+                    d_id1_to_track[v['id1']].add(keyframe=keyframe, bbox=bbox)
                 
         # Add tracks to scene
         for (k,v) in d_id1_to_track.items():
@@ -276,6 +274,7 @@ class KF1(object):
                     act2 = v['act']['act2']
                     if isinstance(act2, set):
                         category = list(act2)[0]
+                        v['act']['act2'] = list(act2)  # for JSON serialization
                     elif isinstance(act2, dict):
                         category = list(act2.keys())[0]
                     else:
@@ -284,6 +283,7 @@ class KF1(object):
                     act3 = v['act']['act3']
                     if isinstance(act3, set):
                         category = list(act3)[0]
+                        v['act']['act3'] = list(act3)  # for JSON serialization
                     elif isinstance(act3, dict):
                         category = list(act3.keys())[0]
                     else:
@@ -301,11 +301,13 @@ class KF1(object):
                 startframe = int(v['act']['timespan'][0]['tsr0'][0])
                 endframe = int(v['act']['timespan'][0]['tsr0'][1])                
                 actorid = [x['id1'] for x in v['act']['actors']]   
-                if actor:                    
+                if True:                    
                     nounid = [d_id1_to_track[a].id() for a in actorid if (a in d_id1_to_track) and (f_activity_to_actor(category).lower() == d_id1_to_track[a].category().lower())]
-                    if len(nounid) == 0:
-                        print('[vipy.dataset.meva.KF1]: activity "%s" without a required primary actor "%s" - SKIPPING' % (category, f_activity_to_actor(category)))
-                        continue
+                    if len(nounid) == 0 and actor:
+                        print('[vipy.dataset.meva.KF1]: Warning - activity "%s" without a required primary actor "%s" - SKIPPING' % (category, f_activity_to_actor(category)))
+                        continue  # skip it
+                    elif len(nounid) == 0:
+                        print('[vipy.dataset.meva.KF1]: Warning - activity "%s" without a required primary actor "%s"' % (category, f_activity_to_actor(category)))
                     nounid = nounid[0] if len(nounid) > 0 else None   # first track in activity of required object class for this category is assumed to be the performer/actor/noun
 
                 for aid in actorid:
